@@ -10,9 +10,9 @@ from .core import scan_packages
 
 class ImportMapExtension(Extension):
 
-    def __init__(self, env: Environment):
-        super().__init__(env)
-        self.env.globals["importmap"] = scan_packages
+    def __init__(self, environment: Environment):
+        super().__init__(environment)
+        environment.globals["importmap"] = scan_packages
 
     def parse(self, parser: Parser) -> Union[Node, List[Node]]:
         raise NotImplementedError
